@@ -4,7 +4,7 @@
 :copyright: (c) 2021 Vladislav117
 """
 
-import geometry
+from .geometry import *
 
 __author__ = "Vladislav117"
 __version__ = "0.0.1"
